@@ -31,7 +31,7 @@ var localDependency = {
 }
 
 var scopedDependency = {
-  name: '@scoped/package',
+  name: '@scoped/package-scoped-dependency',
   version: '0.0.0',
   description: 'Test for local installs'
 }
@@ -64,6 +64,7 @@ test('installing already installed local scoped package', function (t) {
   common.npm(
     [
       '--loglevel', 'silent',
+      '--parseable',
       'install'
     ],
     EXEC_OPTS,
@@ -71,14 +72,13 @@ test('installing already installed local scoped package', function (t) {
       var installed = parseNpmInstallOutput(stdout)
       t.ifError(err, 'install ran to completion without error')
       t.notOk(code, 'npm install exited with code 0')
-
       t.ok(
-        existsSync(path.join(modules, '@scoped', 'package', 'package.json')),
+        existsSync(path.join(modules, '@scoped', 'package-scoped-dependency', 'package.json')),
         'package installed'
       )
       t.ok(
-        contains(installed, 'node_modules/@scoped/package'),
-        'installed @scoped/package'
+        contains(installed, 'node_modules/@scoped/package-scoped-dependency'),
+        'installed @scoped/package-scoped-dependency'
       )
       t.ok(
         contains(installed, 'node_modules/package-local-dependency'),
@@ -88,6 +88,7 @@ test('installing already installed local scoped package', function (t) {
       common.npm(
         [
           '--loglevel', 'silent',
+          '--parseable',
           'install'
         ],
         EXEC_OPTS,
@@ -98,13 +99,13 @@ test('installing already installed local scoped package', function (t) {
           installed = parseNpmInstallOutput(stdout)
 
           t.ok(
-            existsSync(path.join(modules, '@scoped', 'package', 'package.json')),
+            existsSync(path.join(modules, '@scoped', 'package-scoped-dependency', 'package.json')),
             'package installed'
           )
 
           t.notOk(
-            contains(installed, 'node_modules/@scoped/package'),
-            'did not reinstall @scoped/package'
+            contains(installed, 'node_modules/@scoped/package-scoped-dependency'),
+            'did not reinstall @scoped/package-scoped-dependency'
           )
           t.notOk(
             contains(installed, 'node_modules/package-local-dependency'),
@@ -124,8 +125,9 @@ test('cleanup', function (t) {
 })
 
 function contains (list, element) {
+  var matcher = new RegExp(element + '$')
   for (var i = 0; i < list.length; ++i) {
-    if (list[i] === element) {
+    if (matcher.test(list[i])) {
       return true
     }
   }
